@@ -12,9 +12,8 @@
 #' @param t_embed Positive integer. Number of embedding for the temporal dimension. Minimum value is equal to 2. Default: NULL (search range 2:30).
 #' @param activ String. Activation function to be used by the forward network. Implemented functions are: "linear", "mish", "swish", "leaky_relu", "celu", "elu", "gelu", "selu", "bent", "softmax", "softmin", "softsign", "softplus", "sigmoid", "tanh". Default: NULL (full-option search).
 #' @param nodes Positive integer. Nodes for the forward neural net. Default: NULL (search range 2:1024).
-#' @param distr String. Distribution to be used by variational model. Implemented distributions are: "normal", "genbeta", "gev", "gpd", "genray", "cauchy", "exp", "logis", "chisq", "gumbel", "laplace", "lognorm", "skewed". Default: NULL (full-option search).
+#' @param distr String. Distribution to be used by variational model. Implemented distributions are: "normal", "cauchy", "gumbel", "laplace", "rayleigh". Default: NULL (full-option search).
 #' @param optim String. Optimization method. Implemented methods are: "adadelta", "adagrad", "rmsprop", "rprop", "sgd", "asgd", "adam". Default: NULL (full-option search).
-#' @param loss_metric String. Loss function for the variational model. Three options: "elbo", "crps", "score". Default: "crps".
 #' @param epochs Positive integer. Default: 30.
 #' @param lr Positive numeric. Learning rate. Default: NULL (search range 0.001:0.1).
 #' @param patience Positive integer. Waiting time (in epochs) before evaluating the overfit performance. Default: epochs.
@@ -61,9 +60,7 @@
 #' @importFrom narray split
 #' @importFrom utils head tail combn
 #' @import torch
-#' @importFrom stats ecdf lm median na.omit quantile density rcauchy rchisq rexp rlnorm rlogis rnorm dcauchy dchisq dexp dlnorm dlogis dnorm pcauchy pchisq pexp plnorm plogis pnorm runif sd var
-#' @importFrom VGAM rgev pgev dgev rgpd pgpd dgpd rlaplace plaplace dlaplace rgenray pgenray dgenray rgumbel dgumbel pgumbel
-#' @importFrom actuar rgenbeta pgenbeta dgenbeta
+#' @importFrom stats ecdf lm median na.omit quantile density runif sd var
 #' @importFrom modeest mlv1 mfv1
 #' @importFrom moments skewness kurtosis
 #' @importFrom greybox ME MAE MSE RMSSE MRE MPE MAPE rMAE rRMSE rAME MASE sMSE sCE
@@ -75,7 +72,7 @@
 #'
 proteus_random_search <- function(n_samp, data, target, future, past = NULL, ci = 0.8, smoother = FALSE,
                                   t_embed = NULL, activ = NULL, nodes = NULL, distr = NULL, optim = NULL,
-                                  loss_metric = "crps", epochs = 30, lr = NULL, patience = 10, latent_sample = 100, verbose = TRUE,
+                                  epochs = 30, lr = NULL, patience = 10, latent_sample = 100, verbose = TRUE,
                                   stride = NULL, dates = NULL, rolling_blocks = FALSE, n_blocks = 4, block_minset = 10,
                                   error_scale = "naive", error_benchmark = "naive", batch_size = 30,
                                   min_default = 1, seed = 42, future_plan = "future::multisession",
@@ -86,27 +83,23 @@ proteus_random_search <- function(n_samp, data, target, future, past = NULL, ci
 
   set.seed(seed)
 
-  past_param <- sampler(past, n_samp, range = future:(2 * future), integer = T)
-  embed_param <- sampler(t_embed, n_samp, range = 2:30, integer = T)
+  past_param <- sampler(past, n_samp, range = future:(2 * future), integer = TRUE)
+  embed_param <- sampler(t_embed, n_samp, range = 2:30, integer = TRUE)
   act_param <- sampler(activ, n_samp, range = c("linear", "mish", "swish", "leaky_relu", "celu", "elu", "gelu", "selu", "bent", "softmax", "softmin", "softsign", "softplus", "sigmoid", "tanh"))
-  node_param <- sampler(nodes, n_samp, range = c(2:1024), integer = T)
-  distr_param <- sampler(distr, n_samp, range = c("normal", "genbeta", "gev", "gpd", "genray", "cauchy", "exp", "logis", "chisq", "gumbel", "laplace", "lognorm", "skewed"))
+  node_param <- sampler(nodes, n_samp, range = c(2:1024), integer = TRUE)
+  distr_param <- sampler(distr, n_samp, range = c("normal", "cauchy", "gumbel", "laplace", "rayleigh"))
   opt_param <- sampler(optim, n_samp, range = c("adam", "adagrad", "adadelta", "sgd", "asgd", "rprop", "rmsprop"))
-  lrn_param <- round(sampler(lr, n_samp, range = seq(0.001, 0.1, length.out = 1000), integer = F), 3)
-  strd_param <- sampler(stride, n_samp, range = 1:3, integer = T)
+  lrn_param <- round(sampler(lr, n_samp, range = seq(0.001, 0.1, length.out = 1000), integer = FALSE), 3)
+  strd_param <- sampler(stride, n_samp, range = 1:3, integer = TRUE)
 
   hyper_params <- list(past_param, embed_param, act_param, node_param, distr_param, opt_param, lrn_param, strd_param)
-  n_cores <- availableCores() - 1
-  high_level <- n_cores%/%2
-  low_level <- n_cores%/%high_level
-  plan(list(tweak(future_plan, workers = high_level), tweak(future_plan, workers = low_level)))
 
-  models <- future_pmap(hyper_params, ~ proteus(data, target, future, past = ..1, ci, smoother,
+  models <- pmap(hyper_params, ~ proteus(data, target, future, past = ..1, ci, smoother,
                                                 t_embed = ..2, activ = ..3, nodes = ..4, distr = ..5, optim = ..6,
-                                                loss_metric, epochs, lr = ..7, patience, latent_sample, verbose,
+                                                epochs, lr = ..7, patience, latent_sample, verbose,
                                                 stride = ..8, dates, rolling_blocks, n_blocks, block_minset,
                                                 error_scale, error_benchmark, batch_size, omit, min_default,
-                                                future_plan, seed), .options = furrr_options(seed = T))
+                                                future_plan, seed))
 
   n_feats <- length(target)
 
